==> cloudfronts3-1.176.0-sources.jar: software/amazon/awsconstructs/services/cloudfronts3/CloudFrontToS3.java <==
package software.amazon.awsconstructs.services.cloudfronts3;

@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-01T21:58:03.850Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cloudfronts3.$Module.class, fqn = "@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3")
public class CloudFrontToS3 extends software.amazon.awscdk.core.Construct {

    protected CloudFrontToS3(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CloudFrontToS3(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public CloudFrontToS3(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.Distribution getCloudFrontWebDistribution() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontWebDistribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Distribution.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getS3BucketInterface() {
        return software.amazon.jsii.Kernel.get(this, "s3BucketInterface", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.Function getCloudFrontFunction() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getCloudFrontLoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontLoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3Props.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3Props.Builder();
        }

        /**
         * Optional user provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps Optional user provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cloudFrontDistributionProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder cloudFrontDistributionProps(final java.lang.Object cloudFrontDistributionProps) {
            this.props.cloudFrontDistributionProps(cloudFrontDistributionProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the CloudFront Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cloudFrontLoggingBucketProps Optional user provided props to override the default props for the CloudFront Logging Bucket. This parameter is required.
         */
        public Builder cloudFrontLoggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps cloudFrontLoggingBucketProps) {
            this.props.cloudFrontLoggingBucketProps(cloudFrontLoggingBucketProps);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param insertHttpSecurityHeaders Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. This parameter is required.
         */
        public Builder insertHttpSecurityHeaders(final java.lang.Boolean insertHttpSecurityHeaders) {
            this.props.insertHttpSecurityHeaders(insertHttpSecurityHeaders);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param loggingBucketProps Optional user provided props to override the default props for the S3 Logging Bucket. This parameter is required.
         */
        public Builder loggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps loggingBucketProps) {
            this.props.loggingBucketProps(loggingBucketProps);
            return this;
        }

        /**
         * Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
         * <p>
         * Enabling Access Logging is a best practice.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param logS3AccessLogs Whether to turn on Access Logs for the S3 bucket with the associated storage costs. This parameter is required.
         */
        public Builder logS3AccessLogs(final java.lang.Boolean logS3AccessLogs) {
            this.props.logS3AccessLogs(logS3AccessLogs);
            return this;
        }

        /**
         * Optional user provided props to provide an originPath that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
         * <p>
         * The string should start with a <code>/</code>, for example <code>/production</code>.
         * <p>
         * @return {@code this}
         * @param originPath Optional user provided props to provide an originPath that CloudFront appends to the origin domain name when CloudFront requests content from the origin. This parameter is required.
         */
        public Builder originPath(final java.lang.String originPath) {
            this.props.originPath(originPath);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3}.
         */
        @Override
        public software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3 build() {
            return new software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> cloudfronts3-2.44.0-sources.jar: software/amazon/awsconstructs/services/cloudfronts3/CloudFrontToS3.java <==
package software.amazon.awsconstructs.services.cloudfronts3;

@javax.annotation.Generated(value = "jsii-pacmak/1.88.0 (build eaabd08)", date = "2023-08-29T02:49:23.975Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cloudfronts3.$Module.class, fqn = "@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3")
public class CloudFrontToS3 extends software.constructs.Construct {

    protected CloudFrontToS3(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CloudFrontToS3(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public CloudFrontToS3(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.Distribution getCloudFrontWebDistribution() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontWebDistribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Distribution.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getS3BucketInterface() {
        return software.amazon.jsii.Kernel.get(this, "s3BucketInterface", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.Function getCloudFrontFunction() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getCloudFrontLoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontLoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3Props.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3Props.Builder();
        }

        /**
         * Optional user provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps Optional user provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cloudFrontDistributionProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder cloudFrontDistributionProps(final java.lang.Object cloudFrontDistributionProps) {
            this.props.cloudFrontDistributionProps(cloudFrontDistributionProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the CloudFront Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cloudFrontLoggingBucketProps Optional user provided props to override the default props for the CloudFront Logging Bucket. This parameter is required.
         */
        public Builder cloudFrontLoggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps cloudFrontLoggingBucketProps) {
            this.props.cloudFrontLoggingBucketProps(cloudFrontLoggingBucketProps);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, providing both this and <code>bucketProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, providing both this and <code>bucketProps</code> will cause an error. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
         * <p>
         * Turning this on will inject default headers and is mutually exclusive with passing custom security headers
         * via the responseHeadersPolicyProps parameter.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param insertHttpSecurityHeaders Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. This parameter is required.
         */
        public Builder insertHttpSecurityHeaders(final java.lang.Boolean insertHttpSecurityHeaders) {
            this.props.insertHttpSecurityHeaders(insertHttpSecurityHeaders);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param loggingBucketProps Optional user provided props to override the default props for the S3 Logging Bucket. This parameter is required.
         */
        public Builder loggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps loggingBucketProps) {
            this.props.loggingBucketProps(loggingBucketProps);
            return this;
        }

        /**
         * Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
         * <p>
         * Enabling Access Logging is a best practice.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param logS3AccessLogs Whether to turn on Access Logs for the S3 bucket with the associated storage costs. This parameter is required.
         */
        public Builder logS3AccessLogs(final java.lang.Boolean logS3AccessLogs) {
            this.props.logS3AccessLogs(logS3AccessLogs);
            return this;
        }

        /**
         * Optional user provided props to provide an originPath that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
         * <p>
         * The string should start with a <code>/</code>, for example <code>/production</code>.
         * <p>
         * @return {@code this}
         * @param originPath Optional user provided props to provide an originPath that CloudFront appends to the origin domain name when CloudFront requests content from the origin. This parameter is required.
         */
        public Builder originPath(final java.lang.String originPath) {
            this.props.originPath(originPath);
            return this;
        }

        /**
         * Optional user provided configuration that cloudfront applies to all http responses.
         * <p>
         * Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
         * ResponseHeadersCorsBehavior to the cloudfront distribution.
         * <p>
         * Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers
         * via <code>insertHttpSecurityHeaders</code> prop. Will throw an error if both <code>insertHttpSecurityHeaders</code> is set to <code>true</code>
         * and ResponseSecurityHeadersBehavior is passed.
         * <p>
         * Default: - undefined
         * <p>
         * @return {@code this}
         * @param responseHeadersPolicyProps Optional user provided configuration that cloudfront applies to all http responses. This parameter is required.
         */
        public Builder responseHeadersPolicyProps(final software.amazon.awscdk.services.cloudfront.ResponseHeadersPolicyProps responseHeadersPolicyProps) {
            this.props.responseHeadersPolicyProps(responseHeadersPolicyProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3}.
         */
        @Override
        public software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3 build() {
            return new software.amazon.awsconstructs.services.cloudfronts3.CloudFrontToS3(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
